@@ -1,5 +1,6 @@
 package Pod::Elemental::Transformer;
-our $VERSION = '0.092500';
+our $VERSION = '0.092900';
+
 
 use Moose::Role;
 use Moose::Autobox;
@@ -7,9 +8,6 @@ use Moose::Autobox;
 
 use namespace::autoclean;
 
-use Pod::Elemental::Element;
-use Pod::Elemental::Element::Command;
-
 requires 'transform_document';
 
 
@@ -25,7 +23,7 @@ Pod::Elemental::Transformer - something that transforms a document tree into a n
 
 =head1 VERSION
 
-version 0.092500
+version 0.092900
 
 =head1 METHODS
 
